---
title: "Auditor Release Notes: Version 1.3.0"
layout: inside
permalink: /Patches/1.3.0.html
lead_content: >
    A list of featured updates to the HTML_CodeSniffer bookmarklet in release version 1.3.0, released on 15th October 2012. This list is focused for users of the bookmarklet, and focuses on changes to tests and the auditor interface. A full list of updates can also be found in the project's technical <a href="https://github.com/squizlabs/HTML_CodeSniffer/blob/gh-pages/CHANGELOG.markdown">bookmarklet changelog</a>.
---

### Auditor Interface
{: #auditor}

#### New or Updated Features
{: #auditor-features}

##### Unable to Point to Element message

When the HTML_CodeSniffer auditor is unable to point to the offending element in an issue, the Issue Details interface now displays a message explaining why. There are many reasons why the pointer may be disabled, including:

* The element is hidden using <abbr title="Cascading Style Sheets">CSS</abbr> styling; for instance using the display or visibility properties.
* The element does not have a visual representation. For instance, inside an image map, AREA elements do not display anything by themselves, but can generate an error if they are lacking alt text.
* The element may have been removed from the document after the report was generated. This may be the case if a page is dynamically updated.
* The element may be located outside the BODY tag of the document. Certain sniffs flag elements located in the head section of the document, or even on the root html element itself.
* The issue may be related to the entire document. This is the case for many of the notices, which only display once at a document level.

##### All issues now listed in DOM order

In previous versions, some issues were listed in Success Criterion order, and others in Document Object Model (DOM) order. This meant that the issue pointer would jump up and down the document with seemingly no reason as to the issue listing order. Now, sniffs should all be listed by their DOM order, thereby minimising this disorientation. (It may still occur if elements are visually placed out of their natural order in the DOM using styling.)

#### Bug Fixes
{: #auditor-bugs}

* In Internet Explorer 8.0 (and later versions with pages parsing in IE8 mode), an "unknown runtime error" would sometimes appear when attempting to change pages in the issue list, if it was placed inside or around invalid HTML. An alternative method has been implemented so this no longer occurs.
* Fixed an issue where the auditor popup would not become semi-transparent in Internet Explorer 8.0 when the pointer is underneath the popup.

### WCAG 2.0 Standards Updates
{: #standards-wcag2}

_References to Principles, Guidelines, Success Criteria and Conformance Requirements should be read in line with the [WCAG 2.0 Recommendation][WCAG20]._

#### Fieldset tests updated (Success Criterion 1.3.1)
{: #standards-wcag2-fieldset}

This version of HTML_CodeSniffer updates the sniff for technique [H71][H71-2012] regarding fieldset and legend elements, bring it up to date with the January 2012 version of the technique. Compared with the [October 2010 version of H71][H71-2010], the following crucial change has been made:

> However, when a group of related radio buttons or checkboxes (even having values for a single named field) includes clear instructions and distinct selections (i.e. where the individual label associated with each particular control provides a sufficient description), the use of the fieldset and legend elements is not required. [H44: Using label elements to associate text labels with form controls][H44-2012] is sufficient in this case. ([cite][H71-2012])

In line with this new interpretation, these tests have been rewritten and messages emitted reduced from an Error to a Warning.

#### Other updates and bug fixes
{: #standards-wcag2-bugs}

* Buttons and hidden inputs weren't being correctly detected in the test for IDs on inputs (in Success Criterion 1.3.1), when the type attribute was not all lowercase (eg. type="Submit").
* Certain sniffs that emit notices now fire on each found element, rather than one fired at the top of the document. This includes audio/video tag sniffs in Guidelines 1.2 and 1.4, as well as input fields in Success Criterion 3.2.1.

[WCAG20]: http://www.w3.org/TR/WCAG20
[H71-2012]: http://www.w3.org/TR/2012/NOTE-WCAG20-TECHS-20120103/H71
[H71-2010]: http://www.w3.org/TR/2012/NOTE-WCAG20-TECHS-20101014/H71
[H44-2012]: http://www.w3.org/TR/2012/NOTE-WCAG20-TECHS-20120103/H44
